@@ -886,8 +886,6 @@ ggv_control_construct (GgvControl *control, GgvPostScriptView *ps_view)
 					 G_CALLBACK(scrollbar_button_release_event),
 					 view);
 	gtk_container_add(GTK_CONTAINER(control->priv->root), view);
-	/* unref the GtkGS acquired from GgvPostScriptView */
-	gtk_widget_unref(view);
 	
 	bonobo_control_construct (BONOBO_CONTROL (control), control->priv->root);
 
