@@ -8,6 +8,7 @@
  */
 
 #ifndef __GGV_WINDOW_H__
+#define __GGV_WINDOW_H__
 
 #include <config.h>
 
@@ -50,10 +51,13 @@ struct _GgvWindow
         GtkWidget *hbox, *vbox;
         GtkWidget *statusbar;
         GtkWidget *popup_menu;
-        GtkWidget *file_sel;
-        GtkWidget *save_file_sel;
 
         gboolean show_menus, show_sidebar, show_toolbar, show_statusbar;
+
+        gboolean fullscreen;
+        gint orig_x, orig_y, orig_width, orig_height;
+        gboolean orig_ss, orig_sss, orig_sm, orig_st;
+
         gboolean loaded;
         gboolean pan;
         gboolean pane_auto_jump;	/* ...to top of new page */
@@ -86,6 +90,7 @@ gboolean  ggv_window_load               (GgvWindow *win, const gchar *filename);
 void      ggv_window_apply_prefs        (GgvWindow *win);
 void      ggv_window_sync_toolbar_style (GgvWindow *win);
 const GList *ggv_get_window_list(void);
+void      ggv_window_destroy_all(void);
 
 G_END_DECLS
 
